@@ -8,7 +8,7 @@
  *
  *   The license which is distributed with this software in the file COPYRIGHT
  *   applies to this software. If your distribution is missing this file, you
- *   may request it from <pekkas@netcore.fi>.
+ *   may request it from <reubenhwk@gmail.com>.
  *
  */
 
@@ -28,7 +28,7 @@
  * the defined prefixes
  */
 int
-setup_deviceinfo(struct Interface *iface)
+update_device_info(struct Interface *iface)
 {
 	struct ifreq	ifr;
 	struct AdvPrefix *prefix;
@@ -37,8 +37,8 @@ setup_deviceinfo(struct Interface *iface)
 	strncpy(ifr.ifr_name, iface->Name, IFNAMSIZ-1);
 	ifr.ifr_name[IFNAMSIZ-1] = '\0';
 
-	if (ioctl(sock, SIOCGIFMTU, &ifr) < 0) {
-		flog(LOG_ERR, "ioctl(SIOCGIFMTU) failed for %s: %s",
+	if (ioctl(sock, SIOCGIFMTU | SIOCGIFHWADDR, &ifr) < 0) {
+		flog(LOG_ERR, "ioctl() failed for %s: %s",
 			iface->Name, strerror(errno));
 		return (-1);
 	}
@@ -46,13 +46,6 @@ setup_deviceinfo(struct Interface *iface)
 	dlog(LOG_DEBUG, 3, "mtu for %s is %d", iface->Name, ifr.ifr_mtu);
 	iface->if_maxmtu = ifr.ifr_mtu;
 
-	if (ioctl(sock, SIOCGIFHWADDR, &ifr) < 0)
-	{
-		flog(LOG_ERR, "ioctl(SIOCGIFHWADDR) failed for %s: %s",
-			iface->Name, strerror(errno));
-		return (-1);
-	}
-
 	dlog(LOG_DEBUG, 3, "hardware type for %s is %d", iface->Name,
 		ifr.ifr_hwaddr.sa_family);
 
